@@ -22,6 +22,8 @@ PARAMETERS = "parameters"
 ACCOUNTS = "accounts"
 MAPPINGS = "mappings"
 LAUNCHES = "launches"
+STACK = "stack"
+STACKS = "stacks"
 SPOKE_LOCAL_PORTFOLIOS = "spoke-local-portfolios"
 LAMBDA_INVOCATIONS = "lambda-invocations"
 ASSERTIONS = "assertions"
@@ -40,13 +42,6 @@ AFFINITY_REGION = "region"
 AFFINITY_ACCOUNT = "account"
 AFFINITY_ACCOUNT_AND_REGION = "account-and-region"
 
-ALL_SECTION_NAMES = [
-    LAUNCHES,
-    SPOKE_LOCAL_PORTFOLIOS,
-    LAMBDA_INVOCATIONS,
-    CODE_BUILD_RUNS,
-    ASSERTIONS,
-]
 
 RESULTS_DIRECTORY = "results"
 
@@ -112,8 +107,19 @@ PRODUCT_GENERATION_METHOD_DEFAULT = "copy"
 
 LUIGI_DEFAULT_LOG_LEVEL = "INFO"
 
+
+ALL_SECTION_NAMES = [
+    LAUNCHES,
+    STACKS,
+    SPOKE_LOCAL_PORTFOLIOS,
+    LAMBDA_INVOCATIONS,
+    CODE_BUILD_RUNS,
+    ASSERTIONS,
+]
+
 ALL_SECTION_NAME_SINGULAR_AND_PLURAL_LIST = [
     (LAUNCH, LAUNCHES),
+    (STACK, STACKS),
     (SPOKE_LOCAL_PORTFOLIO, SPOKE_LOCAL_PORTFOLIOS),
     (LAMBDA_INVOCATION, LAMBDA_INVOCATIONS),
     (CODE_BUILD_RUN, CODE_BUILD_RUNS),
@@ -122,12 +128,14 @@ ALL_SECTION_NAME_SINGULAR_AND_PLURAL_LIST = [
 
 SECTION_NAME_SINGULAR_AND_PLURAL_LIST_THAT_SUPPORTS_PARAMETERS = [
     (LAUNCH, LAUNCHES),
+    (STACK, STACKS),
     (LAMBDA_INVOCATION, LAMBDA_INVOCATIONS),
     (CODE_BUILD_RUN, CODE_BUILD_RUNS),
 ]
 
 SECTION_SINGULAR_TO_PLURAL = {
     LAUNCH: LAUNCHES,
+    STACK: STACKS,
     SPOKE_LOCAL_PORTFOLIO: SPOKE_LOCAL_PORTFOLIOS,
     LAMBDA_INVOCATION: LAMBDA_INVOCATIONS,
     CODE_BUILD_RUN: CODE_BUILD_RUNS,
